@@ -1,6 +1,7 @@
 from rest_framework.decorators import action
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, TreeAPIView
 from rest_framework.response import Response
+from rest_framework.permissions import IsAuthenticatedOrReadOnly
 
 from .models import Category
 from .serializers import CategorySerializer
@@ -18,6 +19,7 @@ class CategoryView(CustomModelViewSet, TreeAPIView):
     filter_backends = [
         DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter]
     ordering_fields = '__all__'
+    permission_classes = [IsAuthenticatedOrReadOnly]
 
     @action(detail=False, methods=['post'], url_path='sort', url_name='sort')
     def sort(self, request, *args, **kwargs):
