@@ -2,7 +2,7 @@ import json
 from asgiref.sync import async_to_sync
 from channels.generic.websocket import WebsocketConsumer
 from bluedot_rest_framework import import_string
-
+from django.db.models import F
 
 EventComment = import_string('EVENT.comment.models')
 EventCommentSerializer = import_string('EVENT.comment.serializers')
@@ -48,18 +48,15 @@ class CommentConsumer(WebsocketConsumer):
             EventComment.objects.create(**data)
         elif state == 1:  # 通过
             _id = text_data_json.get('id', None)
-            # data = text_data_json.get('data', None)
             event_queryset = EventComment.objects.get(pk=_id)
             event_queryset.state = 1
-            # event_queryset.data = data
             event_queryset.save()
-            # data = EventCommentSerializer(
-            #     EventComment.objects.get(pk=_id)).data
+            data = EventCommentSerializer(event_queryset).data
             async_to_sync(self.channel_layer.group_send)(
                 self.room_group_name,
                 {
-                    'type': 'event_chat_message',
-                    **data, id: _id
+                    'type': 'event_comment_message',
+                    **data
                 }
             )
         elif state == 2:  # 拒绝
@@ -74,20 +71,17 @@ class CommentConsumer(WebsocketConsumer):
                 'openid': text_data_json.get('openid', None),
                 'comment_id': text_data_json.get('comment_id', None),
             }
+            event_comment_queryset = EventComment.objects.get(
+                pk=data['comment_id'])
             if state == 3:
                 EventCommentLike.objects.create(**data)
-                EventComment_queryset = EventComment.objects.get(
-                    pk=data['comment_id'])
-                EventComment_queryset.inc__like_count = 1
-                EventComment_queryset.save()
+                event_comment_queryset.like_count = F('like_count') + 1
             else:
                 queryset = EventCommentLike.objects.filter(**data)
                 if queryset:
                     queryset.delete()
-                    EventComment_queryset = EventComment.objects.get(
-                        pk=data['comment_id'])
-                EventComment_queryset.inc__like_count = 1
-
+                    event_comment_queryset.like_count = F('like_count') - 1
+            event_comment_queryset.save()
             queryset = EventComment.objects.get(pk=data['comment_id'])
             send_data = {
                 'comment_id': data['comment_id'],
@@ -118,7 +112,7 @@ class CommentConsumer(WebsocketConsumer):
                 }
             )
 
-    def event_comment_message(self, event):
+    def event_comment_message(self, data):
         self.send(text_data=json.dumps({
-            **event
+            **data
         }))
