@@ -4,7 +4,6 @@ from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create, AllView
 from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler
 
-
 EventComment = import_string('EVENT.comment.models')
 EventCommentSerializer = import_string('EVENT.comment.serializers')
 EventCommentLike = import_string('EVENT.comment.like_models')
@@ -14,10 +13,20 @@ EventCommentLikeSerializer = import_string('EVENT.comment.like_serializers')
 class EventCommentView(CustomModelViewSet):
     model_class = EventComment
     serializer_class = EventCommentSerializer
+
     filterset_fields = {
-        'event_id': ['exact'],
-        'schedule_id': ['exact'],
-        'state': ['exact']
+        'state': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+        'schedule_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
     }
 
     def perform_create(self, serializer):
@@ -30,7 +39,7 @@ class EventCommentView(CustomModelViewSet):
         data = self.get_serializer(queryset, many=True).data
         for item in data:
             item['is_like'] = 0
-            if EventCommentLike.objects.filter(user_id=user_id, id=item['id']):
+            if EventCommentLike.objects.filter(user_id=user_id, comment_id=item['id']):
                 item['is_like'] = 1
         return Response(data)
 
