@@ -1,6 +1,7 @@
 from rest_framework import status
 from rest_framework.response import Response
 from bluedot_rest_framework import import_string
+from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create
 from bluedot_rest_framework.utils.jwt_token import jwt_get_openid_handler
 
@@ -15,6 +16,7 @@ class EventQuestionView(CustomModelViewSet):
     model_class = EventQuestion
     serializer_class = EventQuestionSerializer
     pagination_class = None
+    permission_classes = [IsAuthenticatedOrReadOnly]
 
     def create(self, request, *args, **kwargs):
         event_id = self.request.data.get('event_id', None)
