@@ -1,11 +1,9 @@
 from rest_framework.decorators import action
 from rest_framework.response import Response
+from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.func import orm_bulk_update
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet
-from rest_framework import filters
-from django_filters.rest_framework.backends import DjangoFilterBackend
-from .filter import EventScheduleFilter
 
 EventSchedule = import_string('EVENT.schedule.models')
 EventScheduleSerializer = import_string('EVENT.schedule.serializers')
@@ -15,11 +13,17 @@ class EventScheduleView(CustomModelViewSet):
     model_class = EventSchedule
     serializer_class = EventScheduleSerializer
     pagination_class = None
-    filterset_class = EventScheduleFilter
-
-    filter_backends = [
-        DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter]
-    ordering_fields = '__all__'
+    filterset_fields = {
+        'topic_title': {
+            'field_type': 'string',
+            'lookup_expr': '__icontains'
+        },
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+    }
+    permission_classes = [IsAuthenticatedOrReadOnly]
 
     def create(self, request, *args, **kwargs):
         data = request.data
